VideoListPlayerController class

A controller class that manages a list of VideoPlayerController objects.

This controller controls the playback of videos, including play, pause, next, and previous. It also supports automatic playback when one video finishes and moves to the next in the list.

Constructors

VideoListPlayerController({required List<VideoPlayerController> controllers, bool? autoMode = true})
Creates a new VideoListPlayerController with the given list of video controllers.

Properties

autoMode bool?
Whether to automatically move to the next video when the current one finishes.
getter/setter pair
controllers List<VideoPlayerController>
A list of VideoPlayerController objects used to play the videos.
final
currentController → VideoPlayerController
Returns the current VideoPlayerController for the video that is currently playing.
no setter
hashCode int
The hash code for this object.
no setterinherited
onUpdate VoidCallback?
A callback that is triggered whenever the video playback state is updated.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

next() Future<void>
Plays the next video in the sequence.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pause() → void
Pauses the current video playback.
play() → void
Starts video playback by playing the current video controller.
previous() Future<void>
Plays the previous video in the sequence.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited