VideoListPlayerController constructor
VideoListPlayerController({})
Creates a new VideoListPlayerController with the given list of video controllers.
The controllers list contains the video controllers to be managed, and the autoMode
indicates whether to automatically play the next video when the current video finishes.
Implementation
VideoListPlayerController({required this.controllers, this.autoMode = true});