play method
void
play()
Starts video playback by playing the current video controller.
It also adds a listener to detect when the video finishes, allowing automatic switching to the next video.
Implementation
void play() {
_removePreviousListener();
currentController.play();
currentController.addListener(_videoListener);
onUpdate?.call();
}